function [Pt,P3,Q1,Q2,indist,outdist] = adb_TP(map1,map2)

%Calculates the topographic product based on nearest-neighbour relations.
%see Bauer & Pawelzik, IEEE Trans Neural Networks, 1992
%  & Yarrow et al., PloS one, 2014
%
%Inputs need to be 2 numeric matrices, representing points in two spaces (both n-by-d matrices containing n points in d dimensions, eg. for 2D [x y;x y;
%etc]. Points need to be matched by location within these matrices i.e they
%should have the same number of rows
%
%Results options:
%Pt gives the mean of the absolute of the log of all P3 in the spaces (as in Yarrow et al 2014).
%P3, Q1 and Q2 are intermediate calculations. 
%indist and outdist are ranked distances in both spaces, and are matched to
%P3.
%
%Usage: [Pt,P3,Q1,Q2,indist,outdist] = adb_TP(map1,map2)
%
% Code written by Andrew D Bard, 2015, for Liewe et al, PloS one, 2015.
% Contact: andrew.bard@kcl.ac.uk, andrew.lowe@kcl.ac.uk


if size(map1,1) ~=size(map2,1) %check if there are the same number of points in both maps
    error('Andrew says: you are silly. These maps do not have the same number of points.')
end

if size(map1,1) < 3 
    warning('less than 3 points in maps. Your result is likely to be either NaN or meaningless. Check inputs')
end

if isnumeric(map1) && isnumeric(map2)
    
    map1 = adb_duplicateshift(map1); %check that no points are in the same place!
    map2 = adb_duplicateshift(map2);
    
    n_points = size(map1,1); %which will also be length(output)
    kmax = n_points-1; %there will only be n_points-1 distances between n points!
    
    %calculate distances between all points
    euclinput = pdist2(map1,map1);
    eucloutput = pdist2(map2,map2);
    
    %replace diagonal with Inf to facilitate sorting i.e they will always be
    %largest
    euclinput(linspace(1,numel(euclinput),length(euclinput))) = Inf;
    eucloutput(linspace(1,numel(eucloutput),length(eucloutput))) = Inf;
    
    %make results matrices
    Q1 = zeros(n_points,kmax,'single');
    Q2 = zeros(n_points,kmax,'single');
    % P1 = zeros(n_points,kmax,'single');
    % P2 = zeros(n_points,kmax,'single');
    P3 = zeros(n_points,kmax,'single');
    
    [indist,kth_in] = sort(euclinput,2,'ascend');%rank distances from each point to all others in input from smallest to largest
    [outdist,kth_out] = sort(eucloutput,2,'ascend');%rank distances from each point to all others in output from smallest to largest
    
    %calculate Q1, Q2 and P1-3 for each value of k, for each point
    for point=1:n_points
        
        for k=1:kmax
            Q1(point,k) = euclinput(point,kth_out(point,k))/euclinput(point,kth_in(point,k));
            Q2(point,k) = eucloutput(point,kth_out(point,k))/eucloutput(point,kth_in(point,k));
            
            if k==1%calculate for first k
                %             P1(point,1) = Q1(point,1);
                %             P2(point,1) = Q2(point,1);
                P3(point,1) = (Q1(point,1)*Q2(point,1)).^(1/2);
            else %calculate for all k using previous value
                %             P1(point,k) = ((P1(point,k-1)^(k-1))*Q1(point,k))^(1/k);
                %             P2(point,k) = ((P2(point,k-1)^(k-1))*Q2(point,k))^(1/k);
                
                P3(point,k) = P3(point,k-1)^((k-1)/k)*...
                    Q1(point,k)^(1/(2*k))*...
                    Q2(point,k)^(1/(2*k));
                
            end
        end
    end

    %Pt according to Yarrow et al
    Pt = mean(mean(abs(log(P3))));
    
elseif iscell(map1) && iscell(map2)
    if numel(map1) ~= numel(map2)
        error('multisubject data is not matched properly')
    end
    nfishies = numel(map1);
    Pt = NaN(nfishies,1);
    P3 = cell(size(map1));
    Q1 = cell(size(map1));
    Q2 = cell(size(map1));
    indist = cell(size(map1));
    outdist = cell(size(map1));
    for f = 1:nfishies
        [Pt(f),Pm{f},P3{f},Q1{f},Q2{f},indist{f},outdist{f}] = adb_TP(map1{f},map2{f});
    end
    
    Pt = mean(Pt);
    
end



end