function [normPt, stdev, p, Pt, shufPts, shuffledmaps] = adb_normPt(map1,map2,nshuffles)

%takes an input map pair, calculates its normalised Pt based on an average of
%Pts for 'nshuffles' different shuffled maps.
%
%Usage: [normPt, stdev, p, Pt, shufPts, shuffledmaps] = adb_normPt(map1,map2,nshuffles)
%
%%map1 and map2 need to be numeric matrices, representing points in two spaces (both n-by-d matrices containing n points in d dimensions, eg. for 2D [x y;x y;
%etc]. Points need to be matched by location within these matrices i.e they
%should have the same number of rows. If cells are provided, their contents
%will be concatenated into a single map pair.
%
%nshuffles gives the number of Pts from randomly permuted versions of the
%map that the Pt is normalised to. Default is 1000. these maps themselves can be exported as a
%cell array (shuffledmaps)
%
%Output options:
%
%normPt is the final, normalised topographic product, with 0 representing
%perfect order and 1 representing complete disorder.
%stdev gives the standard deviation of this value, calculated from the
%individual ratios of Pt/shuffled Pts.
%p reports a p-value for whether topographic order is present, from Monte
%Carlo analysis (see Yarrow et al., PloS one, 2014)
%Pt gives the Pt of the real map pair, while shufPts gives the
%individual Pts of the shuffled map pairs. 
%Additionally, shuffled versions of map2 are provided in the cell
%shuffledmaps.
%
% Code written by Andrew D Bard, 2015, for Liewe et al, PloS one, 2015.
% Contact: andrew.bard@kcl.ac.uk, andrew.lowe@kcl.ac.uk

if ~exist('nshuffles','var')
    nshuffles = 1000;
end

%if the input is a cell, return message that another analysis might be more
%appropriate, but that a standard normalised Pt will be computed anyway
if iscell(map1)
    map1 = vertcat(map1{:});
    warning('First map contains multi-subject data. Another analysis might be more appropriate, but the normalised topographic product will be computed on combined maps')
end

if iscell(map2)
    map2 = vertcat(map2{:});
    warning('Second map contains multi-subject data. Another analysis might be more appropriate, but the normalised topographic product will be computed on combined maps')
end


Pt = adb_TP(map1,map2);

%shufPts = Inf(1,nshuffles);
shufPts = zeros(1,nshuffles);

if nshuffles > 1
    progressbar('Shuffling the maps');
end


failcount = 0;
shuffledmaps = cell(nshuffles,1);


for shuf = 1:nshuffles
    shuffledmaps{shuf} = adb_shufflemap(map2);
    returned_Pts = adb_TP(map1,shuffledmaps{shuf});
    
    while isinf(returned_Pts)==1
        failcount = failcount+1; %i.e. count number of times the loop is executed in total
        shuffledmaps{shuf} = adb_shufflemap(map2);
        returned_Pts = adb_TP(map1,shuffledmaps{shuf});
    end
    
    shufPts(shuf) = returned_Pts;

    if nshuffles > 1 && mod(shuf,100)==0
         progressbar(shuf/nshuffles)
    end
end
progressbar(1);

%calculate p value
accurate = shufPts < Pt;

p = (sum(accurate)+1)/(nshuffles+1);

%final output
norm = Pt./shufPts;
stdev = std(norm);
normPt = mean(norm);

end
