function asl_combined_dLGN_analyses(LGNcells, LGNborder,code,name,exclude_list,view_col)
%%
%
% asl_combined_dLGN_analyses(LGNcells, LGNborder,code,name,exclude_list,[view_col])
%
% This code takes coordinates of LGNcells within a standardised space which has a border defined by points LGNborder.
%
% These scripts: 
% 1) Examine columns and provide some summary views to help cross-check/evaluate the data.
% 2) Makes splined columns and outputs 3D maps. Leaves one open for manual orientation
% 3) Makes collapsed column using spline as a guide.
% 4) Examines collapsed column using pca to find principal axes of variance.
% 5) Makes a normalised column of all cells.

% Input variables:
% LGNcells - structured array with coordinate information for cells - return with additional information.
%   Animal = unique code for the subject
%   InjColour = unique code for the colour of the beads used
%   LGNxyz = array of N cells and 3 coordinates xyz 
% LGNborder -  coordinates of border - Nx3 (xyz).
% code - for axis limits of images 1 for WT and B2; 2 for P6; 3 for P12 -
%   used to set axes for viewing figures 
% name - string name for outputs: picture and final data files ie. 'WT'
% exclude_list - array of columns to be excluded i.e. [6 12 24] if none then []
% view_col - give any value to get outputs of individual columns. 
%   Stops script at each col and allows user to save the figure.
%
% Saved Output variables:
% LGNcells.spline_col - splined_column
% LGNcells.straightened_column - straightened column based on 10th
%   percentile of column extended out
% LGNcells.collapsed_column - (num_cell,5) collapsed straightened column
% LGN.cells.collapsed_column (:,1:2) - x and y of collapsed column
% LGN.cells.collapsed_column (:,3) - index position on the splined col
% LGN.cells.collapsed_column (:,4) - distance along column in units of coords 
% LGN.cells.collapsed_column (:,5) - tangential distance from col
% LGNcells.pca_gradients - gradients of principle and secondary components
% LGNcells.pcs_con - eigenvalues of the pca (cumsum of latent)
% LGNcells.length_col - length of column.
% LGNborder - as per inputs
% code - as per inputs
% exclude_list - as per inputs
% normed_col - 2D matrix x=relative distance 0-1 y=distance from cell to splined column
% 
% Other variables are intermediate steps.
%
% ASL - 4/12/2015 andrew.lowe@kcl.ac.uk
%%

disp('Starting...');
% 1
if exist('view_col','var')
LGNcells = asl_load_and_realign_columns(LGNcells, exclude_list, view_col);
else
LGNcells = asl_load_and_realign_columns(LGNcells,  exclude_list);
end

% 2
LGNcells = asl_make_projections_map(name,LGNcells, LGNborder,code,exclude_list);

%3
LGNcells = asl_collapse_column(name,LGNcells, LGNborder,exclude_list);

% 4
LGNcells = asl_make_centroid_projection_profile_map_final(name,LGNcells,LGNborder, exclude_list,code);

% 5
normed_col = asl_produce_normalised_column([name,'_normed_col'],LGNcells,exclude_list);

save([name,'_analysed.mat'],'LGNcells','LGNborder','normed_col','exclude_list','code');

disp('End');
end